/*
 * Simple example of parsing and printing JSON using jansson.
 *
 * SYNOPSIS:
 * $ examples/simple_parse
 * Type some JSON > [true, false, null, 1, 0.0, -0.0, "", {"name": "barney"}]
 * JSON Array of 8 elements:
 *   JSON True
 *   JSON False
 *   JSON Null
 *   JSON Integer: "1"
 *   JSON Real: 0.000000
 *   JSON Real: -0.000000
 *   JSON String: ""
 *   JSON Object of 1 pair:
 *     JSON Key: "name"
 *     JSON String: "barney"
 *
 * Copyright (c) 2014 Robert Poor <rdpoor@gmail.com>
 *
 * Jansson is free software; you can redistribute it and/or modify
 * it under the terms of the MIT license. See LICENSE for details.
 */
#include "stdafx.h"
#include <windows.h>
#include "resource.h"
#include <stdio.h>
#include <stdlib.h>
#include <jansson.h>


/* ================================================================
 * main
 */

#define MAX_CHARS 4096

 


 
char* xx_json_object(json_t *element, int indent) {
    size_t size;
    const char *key;
    json_t *value;
	char *result=0;
    const char* type="";
	json_t * jsonType = json_object_get(element,"type");
	json_t * jsonPayload = json_object_get(element,"payload");
	if(jsonType!=NULL && jsonPayload!=NULL)
	{
		type = json_string_value(jsonType);
		if(strcmp(type,"barcode")==0)
		{
			json_t* jsonBarcode = json_object_get(jsonPayload,"barcode");
			if(jsonBarcode!=NULL){
				const char* barcode = json_string_value(jsonBarcode); 
				result = (char*)malloc( strlen(barcode) + 64 );
				sprintf(result,"<type>barcode</type><data>%s</data>",barcode);
				return result;	
			}
		}else if(strcmp(type,"image")==0)
		{
			//wprintf(L"get image \n");
			json_t* jsonImage = json_object_get(jsonPayload,"image");
			if(jsonImage!=NULL){
				//wprintf(L"get image 2 \n");
				const char* image = json_string_value(jsonImage); 
				result =(char*) malloc( strlen(image) + 64 );
				sprintf(result,"<type>picture</type><data>%s</data>",image);
				/*int len;
				void *NewBase64Decode(const char *inputBuffer,int length,int *outputLength);
				char* pcode = (char*)NewBase64Decode(image,strlen(image),&len);
				FILE* f = fopen(__FLASHDISK__ "\\1.png","wb");
				if(f){
					fwrite(pcode,1,len,f);
					fclose(f);
				}*/
				return result;	
				 
			}
		}else if(strcmp(type,"signature")==0)
		{
			json_t* jsonSignature = jsonPayload;//json_object_get(jsonPayload,"signature");
			if(jsonSignature!=NULL){
				json_t* jsonFirst = json_object_get(jsonSignature,"firstName");
				json_t* jsonLast = json_object_get(jsonSignature,"lastName");
				json_t* jsonImage = json_object_get(jsonSignature,"image");
				const char* image = json_string_value(jsonImage); 
				const char* first = jsonFirst?json_string_value(jsonFirst):"";
				const char* last =  jsonLast?json_string_value(jsonLast):"";
				result =(char*) malloc( strlen(image) + 128 );
				sprintf(result,"<type>signature</type><firstName>%s</firstName><lastName>%s</lastName><data>%s</data>",first,last,image);
				return result;	
			}
		}  
    }
	return NULL;

}
json_t *load_json(const char *text) ;
char* parse_json(char* path)
{
	FILE *f = fopen(path,"rb");
	if(!f) return 0;
	char * line;
	long l = fseek(f,0,SEEK_END);
	l= ftell(f);
	fseek(f,0,SEEK_SET);
	

	line =(char*) malloc(l+1);
	fread( line,1, l, f);
	line[l]=0;
	char* result = NULL ;
    
    /* parse text into JSON structure */
    json_t *root = load_json(line);
	
    if (root) {
        /* print and release the JSON structure */
         result = xx_json_object(root,0);
		//print_json(root);
        json_decref(root);
    }
	free(line);
	return result;
}


 
 
		
 
 

